#ifndef NT2_CORE_INCLUDE_FUNCTIONS_FINDJ_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_FINDJ_HPP_INCLUDED

#include <nt2/core/functions/findj.hpp>
#include <nt2/core/functions/expr/findj.hpp>

#endif
